@@ -1,10 +1,12 @@
-use solana_faucet::faucet::{request_airdrop_transaction, run_local_faucet};
-use solana_sdk::{
-    hash::Hash,
-    message::Message,
-    signature::{Keypair, Signer},
-    system_instruction,
-    transaction::Transaction,
+use {
+    solana_faucet::faucet::{request_airdrop_transaction, run_local_faucet},
+    solana_sdk::{
+        hash::Hash,
+        message::Message,
+        signature::{Keypair, Signer},
+        system_instruction,
+        transaction::Transaction,
+    },
 };
 
 #[test]
